from .base import Base

import os


class Dbpw(Base):
    """Generates Database PW from AWS"""

    def run(self):
        os.system("aws ssm get-parameter --name \"/local/CFG_MYSQL_MASTER_PASS\" --with-decryption --query 'Parameter.Value' --output text")





class Base(object):

    def __init__(self, path, options, *args, **kwargs):
        self.options = options
        self.args = args
        self.kwargs = kwargs
        self.path = path
        
    def run(self):
        raise NotImplementedError('You must implement the run() method yourself!')
        


from .base import Base

import os


class Jooq(Base):
    """Generates Jooq"""

    def run(self):
        javaPath = os.path.join(self.path, "hbng/java")
        os.chdir(javaPath)
        os.system("./gradlew generateJooq")


from .base import Base

import os, subprocess


class Build(Base):
    """Builds the java, php, flyway or sql containers"""

    def run(self):
        javaPath = os.path.join(self.path, "hbng/java")
        phpPath = os.path.join(self.path, "hbng/php")
        hbngPath = os.path.join(self.path, "hbng")

        # This needs to be a blocking call, otherwise there could be an issue when removing the containers
        subprocess.Popen("docker-compose stop", shell=True, stdout=subprocess.PIPE, cwd=javaPath).wait()

        if self.options["-c"]:
            os.chdir(javaPath)
            os.system("docker rm hbng_changelog_1")
            os.system("docker rmi java/changelog")
            os.system("./gradlew changelog:distDocker")
        if self.options["-m"]:
            os.chdir(javaPath)
            os.system("docker rm hbng_migrations_1")
            os.system("docker rmi java/migrations")
            os.system("./gradlew migrations:clean")
            os.system("./gradlew migrations:jar")
            os.system("./gradlew migrations:distDocker")
        if self.options["-s"]:
            os.chdir(javaPath)
            os.system("docker rm hbng_mysql_1")
        if self.options["-a"]:
            os.chdir(phpPath)
            os.system("docker build -t hb_api .")
        if self.options["-x"]:
            os.chdir(phpPath)
            os.system("docker build --no-cache -t hb_api .")
        if self.options["-n"]:
            subprocess.Popen("npm run webpack -- -d", shell=True, stdout=subprocess.PIPE, cwd=hbngPath)

        subprocess.Popen("docker-compose up -d", shell=True, stdout=subprocess.PIPE, cwd=javaPath).wait()



from .base import Base

import os

class Test(Base):
    """Runs backend, frontend, or integration tests"""
    def run(self):
        java_path = os.path.join(self.path, "hbng/java")
        hbng_path = os.path.join(self.path, "hbng")
        test_path = os.path.join(self.path, "hbng/test")

        if self.options["be"]:
            os.chdir(java_path)
            os.system("./gradlew clean build test")
        elif self.options["app"]:
            os.chdir(hbng_path)
            os.system("npm run test-app")
        elif self.options["admin"]:
            os.chdir(hbng_path)
            os.system("npm run test-admin")
        elif self.options["core"]:
            os.chdir(hbng_path)
            os.system("npm run test-core")
        elif self.options["it"]:
            os.chdir(test_path)
            os.system("npm run mocha --env=local")



from .base import Base

import os


class Watch(Base):

    def run(self):
        hbngPath = os.path.join(self.path, "hbng")

        os.chdir(hbngPath)
        os.system('npm run webpack -- -d --watch')
